#!/bin/sh
# /etc/profile.d/zzzz_no_colorls.sh: v4 2008/11/18 KELEMEN Peter <Peter.Kelemen@cern.ch>

# Objective: strip --color=(always|auto|force|if-tty|tty|yes) options from
# aliases that call ls(1).  Keep old aliases with "__color_" prefix.

# Rationale: potentially saves lots of stat() calls that ls(1) issues to
# determine file type for coloring, which are a pain on busy AFS clients.

# Check if there are any aliases with "ls" defined.
__x=$( alias | grep -w ls | sed 's/^alias //;s/=.*$//' )
if [ -n "$__x" ]; then
	# Check and store globbing status, disable globbing.
	__set_f=0
	case $- in
		*f*)
			__set_f=1
			;;
		*)
			set -f
			;;
	esac

	# Loop over potential aliases for processing.
	__c=__color_
	for i in $__x; do

		# Skip over aliases that probably we have created in a previous run.
		case "${i}" in
			${__c}*)
				continue
				;;
		esac

		# Fetch alias definition.
		__a="$( alias $i )"
		__a="${__a#*=}"		# strip name and equal sign
		__a="${__a#\'}"		# strip leading apostrophe
		__a="${__a%\'}"		# strip trailing apostrophe

		# Process alias word by word.
		__m=0
		__n=""
		for j in $__a; do
			case "$j" in
				# Strip option (by excluding it from construction).
				--color=always|--color=auto|--color=force|--color=if-tty|--color=tty|--color=yes)
					__m=1
					continue
					;;
				# Construct new command line.
				*)
					__n="${__n:+${__n} }${j}"
					;;
			esac
		done

		# Bail out if we didn't find offending --color option.
		if [ $__m = 0 ]; then
			continue
		fi

		# Save old alias.
		alias "${__c}${i}=${__a}"

		# Create new alias.
		if [ "$__n" = "ls" ]; then
			# Get rid of useless collapsed alias.
			unalias ls
		else
			alias "${i}=${__n}"
		fi
	done

	# Enable globbing if it was enabled originally.
	if [ "$__set_f" = 0 ]; then
		set +f
	fi

	unset i
	unset j
	unset __set_f
	unset __a
	unset __c
	unset __m
	unset __n
fi
unset __x

# vim: nowrap number
# End of file.
